@@ -467,9 +467,10 @@ void ContainmentItem::processMimeData(QMimeData *mimeData, int x, int y, KIO::Dr
             // directly create if only one offer only if the containment didn't pass an existing plugin
         } else if (seenPlugins.count() == 1) {
             selectedPlugin = seenPlugins.constBegin().key();
+            const QString mimeDataType = pluginFormats[selectedPlugin];
+            const QVariant mimeDataData = mimeData->data(mimeDataType);
             Plasma::Applet *applet = createApplet(selectedPlugin, QVariantList(), QRect(x, y, -1, -1));
-            setAppletArgs(applet, pluginFormats[selectedPlugin], mimeData->data(pluginFormats[selectedPlugin]));
-
+            setAppletArgs(applet, mimeDataType, mimeDataData);
         } else {
             QHash<QAction *, QString> actionsToPlugins;
             for (const auto &info : std::as_const(seenPlugins)) {
@@ -480,11 +481,13 @@ void ContainmentItem::processMimeData(QMimeData *mimeData, int x, int y, KIO::Dr
                     action = new QAction(info.name(), m_dropMenu);
                 }
                 m_dropMenu->addAction(action);
-                action->setData(info.pluginId());
-                connect(action, &QAction::triggered, this, [this, x, y, mimeData, action]() {
-                    const QString selectedPlugin = action->data().toString();
+                const QString selectedPlugin = info.pluginId();
+                const QString mimeDataType = pluginFormats[selectedPlugin];
+                const QVariant mimeDataData = mimeData->data(mimeDataType);
+
+                connect(action, &QAction::triggered, this, [this, x, y, selectedPlugin, mimeDataType, mimeDataData]() {
                     Plasma::Applet *applet = createApplet(selectedPlugin, QVariantList(), QRect(x, y, -1, -1));
-                    setAppletArgs(applet, selectedPlugin, mimeData->data(selectedPlugin));
+                    setAppletArgs(applet, mimeDataType, mimeDataData);
                 });
 
                 actionsToPlugins.insert(action, info.pluginId());
@@ -533,13 +536,19 @@ void ContainmentItem::mimeTypeRetrieved(KIO::Job *job, const QString &mimetype)
         return;
     }
 
+    QPoint sceneDropPoint = m_dropMenu->globalDropPoint();
+    if (window()) {
+        // Map The drop point in screen coordinates to scene coordinates
+        sceneDropPoint -= window()->position();
+    }
+
     QList<KPluginMetaData> appletList = Plasma::PluginLoader::self()->listAppletMetaDataForUrl(tjob->url());
     if (mimetype.isEmpty() && appletList.isEmpty()) {
         clearDataForMimeJob(job);
         qCDebug(LOG_PLASMAQUICK) << "No applets found matching the url (" << tjob->url() << ") or the mimetype (" << mimetype << ")";
         return;
     } else {
-        qCDebug(LOG_PLASMAQUICK) << "Received a suitable dropEvent at " << m_dropMenu->dropPoint();
+        qCDebug(LOG_PLASMAQUICK) << "Received a suitable dropEvent at global" << m_dropMenu->globalDropPoint() << "local" << sceneDropPoint;
         qCDebug(LOG_PLASMAQUICK) << "Bailing out. Cannot find associated dropEvent related to the TransferJob";
 
         qCDebug(LOG_PLASMAQUICK) << "Creating menu for: " << mimetype;
@@ -570,11 +579,11 @@ void ContainmentItem::mimeTypeRetrieved(KIO::Job *job, const QString &mimetype)
                 m_dropMenu->addAction(installPlasmaPackageAction);
 
                 const QString &packagePath = tjob->url().toLocalFile();
-                connect(installPlasmaPackageAction, &QAction::triggered, this, [this, packagePath]() {
+                connect(installPlasmaPackageAction, &QAction::triggered, this, [this, packagePath, sceneDropPoint]() {
                     using namespace KPackage;
 
                     PackageJob *job = PackageJob::update(QStringLiteral("Plasma/Applet"), packagePath);
-                    connect(job, &KJob::finished, this, [this, packagePath, job]() {
+                    connect(job, &KJob::finished, this, [this, packagePath, job, sceneDropPoint]() {
                         auto fail = [](const QString &text) {
                             KNotification::event(QStringLiteral("plasmoidInstallationFailed"),
                                                  i18n("Package Installation Failed"),
@@ -597,7 +606,7 @@ void ContainmentItem::mimeTypeRetrieved(KIO::Job *job, const QString &mimetype)
                             return;
                         }
 
-                        createApplet(package.metadata().pluginId(), QVariantList(), QRect(m_dropMenu->dropPoint(), QSize(-1, -1)));
+                        createApplet(package.metadata().pluginId(), QVariantList(), QRect(sceneDropPoint, QSize(-1, -1)));
                     });
                 });
             }
@@ -615,8 +624,8 @@ void ContainmentItem::mimeTypeRetrieved(KIO::Job *job, const QString &mimetype)
                 m_dropMenu->addAction(action);
                 action->setData(info.pluginId());
                 const QUrl url = tjob->url();
-                connect(action, &QAction::triggered, this, [this, action, mimetype, url]() {
-                    Plasma::Applet *applet = createApplet(action->data().toString(), QVariantList(), QRect(m_dropMenu->dropPoint(), QSize(-1, -1)));
+                connect(action, &QAction::triggered, this, [this, action, mimetype, url, sceneDropPoint]() {
+                    Plasma::Applet *applet = createApplet(action->data().toString(), QVariantList(), QRect(sceneDropPoint, QSize(-1, -1)));
                     setAppletArgs(applet, mimetype, url);
                 });
             }
@@ -625,8 +634,8 @@ void ContainmentItem::mimeTypeRetrieved(KIO::Job *job, const QString &mimetype)
                 m_dropMenu->addAction(action);
                 action->setData(QStringLiteral("org.kde.plasma.icon"));
                 const QUrl url = tjob->url();
-                connect(action, &QAction::triggered, this, [this, action, mimetype, url]() {
-                    Plasma::Applet *applet = createApplet(action->data().toString(), QVariantList(), QRect(m_dropMenu->dropPoint(), QSize(-1, -1)));
+                connect(action, &QAction::triggered, this, [this, action, mimetype, url, sceneDropPoint]() {
+                    Plasma::Applet *applet = createApplet(action->data().toString(), QVariantList(), QRect(sceneDropPoint, QSize(-1, -1)));
                     setAppletArgs(applet, mimetype, url);
                 });
             }
@@ -666,7 +675,7 @@ void ContainmentItem::mimeTypeRetrieved(KIO::Job *job, const QString &mimetype)
             }
             // case in which we created the menu ourselves, just the "fetching type entry, directly create the icon applet
         } else if (!m_dropMenu->isDropjobMenu()) {
-            Plasma::Applet *applet = createApplet(QStringLiteral("org.kde.plasma.icon"), QVariantList(), QRect(m_dropMenu->dropPoint(), QSize(-1, -1)));
+            Plasma::Applet *applet = createApplet(QStringLiteral("org.kde.plasma.icon"), QVariantList(), QRect(sceneDropPoint, QSize(-1, -1)));
             setAppletArgs(applet, mimetype, tjob->url());
         }
         clearDataForMimeJob(tjob);
